@@ -75,3 +75,63 @@ def test_validate_default_or_values():
     with pytest.raises(ConfigError) as err:
         Config.create_config("config1", default="value1", value2="value2")
     assert str(err.value) == "You cannot set the default value AND default values for sub values"
+
+
+def test_config_call_if_call():
+    Config.create_config("config", enabled=True)
+    called = False
+
+    @Config.call_if("config.enabled")
+    def call():
+        nonlocal called
+        called = True
+
+    call.called = lambda: called
+
+    call()
+    assert call.called()
+
+
+def test_config_call_if_dont_call():
+    Config.create_config("config", enabled=False)
+    called = False
+
+    @Config.call_if("config.enabled")
+    def call():
+        nonlocal called
+        called = True
+
+    call.called = lambda: called
+
+    call()
+    assert call.called() is False
+
+
+def test_config_call_if_call_compare_with_value():
+    Config.create_config("config", inner={"value": "value"})
+    called = False
+
+    @Config.call_if("config.inner.value", "value")
+    def call():
+        nonlocal called
+        called = True
+
+    call.called = lambda: called
+
+    call()
+    assert call.called()
+
+
+def test_config_call_if_dont_call_compare_with_value():
+    Config.create_config("config", value="value")
+    called = False
+
+    @Config.call_if("config.value", "other_value")
+    def call():
+        nonlocal called
+        called = True
+
+    call.called = lambda: called
+
+    call()
+    assert call.called() is False
